/*
 * Copyright 2010-2024 Australian Signals Directorate
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package au.gov.asd.tac.constellation.views.conversationview;

import au.gov.asd.tac.constellation.views.JavaFxTopComponent;
import javafx.application.Platform;
import org.netbeans.api.settings.ConvertAsProperties;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Top component which displays the Conversation View. The conversation view
 * displays content on nodes and transactions in the graph in a chat style
 * window.
 *
 * @see Conversation
 * @see ConversationBox
 */
@ConvertAsProperties(
        dtd = "-//au.gov.asd.tac.constellation.views.conversationview//ConversationView//EN",
        autostore = false
)
@TopComponent.Description(
        preferredID = "ConversationViewTopComponent",
        iconBase = "au/gov/asd/tac/constellation/views/conversationview/resources/conversation_view.png",
        persistenceType = TopComponent.PERSISTENCE_ALWAYS
)
@TopComponent.Registration(
        mode = "explorer",
        openAtStartup = false
)
@ActionID(
        category = "Window",
        id = "au.gov.asd.tac.constellation.views.conversationview.ConversationViewTopComponent"
)
@ActionReferences({
    @ActionReference(path = "Menu/Views", position = 300),
    @ActionReference(path = "Shortcuts", name = "CS-C")
})
@TopComponent.OpenActionRegistration(
        displayName = "#CTL_ConversationViewAction",
        preferredID = "ConversationViewTopComponent"
)
@Messages({
    "CTL_ConversationViewAction=Conversation View",
    "CTL_ConversationViewTopComponent=Conversation View",
    "HINT_ConversationViewTopComponent=Conversation View"
})
public final class ConversationViewTopComponent extends JavaFxTopComponent<ConversationBox> {

    private final Conversation conversation = new Conversation();
    private final ConversationBox conversationBox;

    public ConversationViewTopComponent() {
        initComponents();
        setName(Bundle.CTL_ConversationViewTopComponent());
        setToolTipText(Bundle.HINT_ConversationViewTopComponent());
        Platform.setImplicitExit(false);
        conversationBox = new ConversationBox(conversation);
        conversation.getGraphUpdateManager().setManaged(true);
        initContent();
    }

    @Override
    protected void handleComponentOpened() {
        super.handleComponentOpened();
        conversation.getGraphUpdateManager().setManaged(true);
    }

    @Override
    protected void handleComponentClosed() {
        super.handleComponentClosed();
        conversation.getGraphUpdateManager().setManaged(false);
    }

    @Override
    protected void componentActivated() {
        conversation.getGraphUpdateManager().setManaged(needsUpdate());
    }

    @Override
    protected void componentDeactivated() {
        conversation.getGraphUpdateManager().setManaged(needsUpdate());
    }

    void writeProperties(java.util.Properties p) {
        // Required for @ConvertAsProperties
    }

    void readProperties(java.util.Properties p) {
        // Required for @ConvertAsProperties
    }

    @Override
    protected String createStyle() {
        return "resources/conversation.css";
    }

    @Override
    protected ConversationBox createContent() {
        return conversationBox;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 400, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 300, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
}
