/*
 * Copyright 2010-2024 Australian Signals Directorate
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package au.gov.asd.tac.constellation.views.mapview.features;

import de.fhpotsdam.unfolding.data.Feature;
import java.util.Collections;
import java.util.HashMap;

/**
 * A feature object for use in the Map View.
 *
 * @author cygnus_x-1
 */
public class ConstellationAbstractFeature {

    public enum ConstellationFeatureType {
        POINT, LINE, POLYGON, MULTI, CLUSTER
    }

    private String id;
    private final ConstellationFeatureType type;
    private HashMap<String, Object> properties = new HashMap<>();

    public ConstellationAbstractFeature(Feature feature) {
        this.id = feature.getId();
        this.type = switch (feature.getType()) {
            case POINT -> ConstellationFeatureType.POINT;
            case LINES -> ConstellationFeatureType.LINE;
            case POLYGON -> ConstellationFeatureType.POLYGON;
            default -> ConstellationFeatureType.MULTI;
        };
        this.properties = feature.getProperties();
    }

    public ConstellationAbstractFeature(ConstellationFeatureType type) {
        this.type = type;
    }

    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }

    public ConstellationFeatureType getType() {
        return type;
    }

    public HashMap<String, Object> getProperties() {
        return (HashMap<String, Object>) Collections.unmodifiableMap(properties);
    }

    public Object getProperty(final String key) {
        return properties.get(key);
    }

    public String getStringProperty(final String key) {
        final Object value = properties.get(key);
        if (value instanceof String string) {
            return string;
        } else {
            return null;
        }
    }

    public Object addProperty(final String key, final Object value) {
        return properties.put(key, value);
    }

    public void setProperties(final HashMap<String, Object> properties) {
        this.properties = properties;
    }
}
