/*
 * Copyright 2010-2024 Australian Signals Directorate
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package au.gov.asd.tac.constellation.views.namedselection.utilities;

import au.gov.asd.tac.constellation.views.namedselection.NamedSelection;
import java.util.List;
import javax.swing.DefaultListModel;
import org.apache.commons.lang3.StringUtils;

/**
 *
 * @author algol
 */
public class SelectNamedSelectionPanel extends javax.swing.JPanel {

    private final List<NamedSelection> namedSelections;

    public SelectNamedSelectionPanel(final List<NamedSelection> namedSelections, String labelText) {
        initComponents();

        this.label.setText(labelText);

        this.namedSelections = namedSelections;

        final DefaultListModel<String> listModel = new DefaultListModel<>();
        for (final NamedSelection ns : namedSelections) {
            final String descr = ns.getDescription();
            final String s = StringUtils.isNotBlank(descr) ? String.format("%s: %s", ns.getName(), ns.getDescription()) : ns.getName();
            listModel.addElement(s);
        }

        nsList.setModel(listModel);
    }

    public long getNamedSelectionId() {
        final int ix = nsList.getSelectedIndex();

        return ix != -1 ? namedSelections.get(ix).getID() : -1;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        label = new javax.swing.JLabel();
        jScrollPane1 = new javax.swing.JScrollPane();
        nsList = new javax.swing.JList<>();

        org.openide.awt.Mnemonics.setLocalizedText(label, org.openide.util.NbBundle.getMessage(SelectNamedSelectionPanel.class, "SelectNamedSelectionPanel.label.text")); // NOI18N

        jScrollPane1.setViewportView(nsList);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jScrollPane1)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(label)
                        .addGap(0, 245, Short.MAX_VALUE)))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(label)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 246, Short.MAX_VALUE)
                .addContainerGap())
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JLabel label;
    private javax.swing.JList<String> nsList;
    // End of variables declaration//GEN-END:variables
}
