/*
 * Copyright 2010-2024 Australian Signals Directorate
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package au.gov.asd.tac.constellation.views.webview;

import java.awt.BorderLayout;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.CloneableTopComponent;
import org.openide.windows.TopComponent;

/**
 * Top component which displays something.
 */
//@ConvertAsProperties(
//        dtd = "-//au.gov.asd.tac.constellation.views.webview//WebView//EN",
//        autostore = false)
@TopComponent.Description(
        preferredID = "WebViewTopComponent",
        iconBase = "au/gov/asd/tac/constellation/webview/resources/webview.png",
        persistenceType = TopComponent.PERSISTENCE_NEVER)
//@TopComponent.Registration(
//        mode = "editor",
//        openAtStartup = false)
//@ActionID(
//        category = "Window",
//        id = "au.gov.asd.tac.constellation.views.webview.WebViewTopComponent")
//@ActionReferences({
//    @ActionReference(path = "Menu/Views" /*, position = 333 */)})
//@TopComponent.OpenActionRegistration(
//        displayName = "#CTL_WebViewAction",
//        preferredID = "WebViewTopComponent")
@Messages({
    "CTL_WebViewAction=Web View",
    "CTL_WebViewTopComponent=Web View",
    "HINT_WebViewTopComponent=Web View"})
public final class WebViewTopComponent extends CloneableTopComponent {

    private final WebViewer webView;

    public WebViewTopComponent() {
        initComponents();
        setName(Bundle.CTL_WebViewTopComponent());
        setToolTipText(Bundle.HINT_WebViewTopComponent());

        webView = new WebViewer();

        add(webView, BorderLayout.CENTER);

        requestActive();
    }

    public WebViewTopComponent(final String name, final String url) {
        initComponents();
        setName(Bundle.CTL_WebViewTopComponent());
        setToolTipText(Bundle.HINT_WebViewTopComponent());

        webView = new WebViewer(url);

        add(webView, BorderLayout.CENTER);

        setName(String.format("%s - %s", name, "Chart Viewer"));
        requestActive();
    }

    public void loadURL(final String url) {
        webView.loadURL(url);
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        setLayout(new java.awt.BorderLayout());
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    @Override
    public void componentOpened() {
        repaint();
    }

    @Override
    public void componentClosed() {
        // Override intentionally left blank
    }
}
